@@ -9,12 +9,10 @@ from inputimeout import inputimeout, TimeoutOccurred
 
 h2r = janda.Hentai2read() 
 
-print(choose().hentai2read)
-async def get_h2r(id: str = choose().hentai2read[0], chapter: int = 1):
+value = choose().hentai2read
+
+async def get_h2r(id: str = value[0], chapter: int = value[1]):
     initial = time.time()
-    ## if chapter is not specified, assign it to 1
-    if chapter == 1:
-        chapter = choose().hentai2read[1]
     data = await h2r.get(id[0], chapter)
     parser = json.loads(data)
     title = parser['title']
