@@ -17,14 +17,20 @@ async def get_nh(id: int = choose().nhentai):
 
     title = parser['details']['title']['pretty']
     title = re.sub(r'[^\w\s]', '', title)
+    number = parser['details']['id']
     print(f'Title: {title}')
 
     img = parser['image_urls']
-    print(f'Total image: {len(img)}')
+    print(f'Total: {len(img)}')
 
-    neat_dir = split_name(__file__) + " - " + title
+    tags = parser['tags']
+    ## jadikan satu variable dari tags list
+    tags = [tag for tag in tags]
+    print(f'Tags: {tags}')
 
-    ## remove all spaces with underscore in neat_dir
+    neat_dir = f'{split_name(__file__)}-{number}-{title}'
+    neat_dir = re.sub('[^A-Za-z0-9-]+', ' ', neat_dir)
+  
     neat_dir = re.sub(r'\s+', '_', neat_dir)
 
     if not os.path.exists(neat_dir):
@@ -46,14 +52,14 @@ async def get_nh(id: int = choose().nhentai):
 
             if os.path.exists(neat_dir + '/' + img_name):
                 print(
-                    f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | in {time.time() - start:.2f} seconds')
+                    f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | took {time.time() - start:.2f} seconds')
 
             if len(img) == len(os.listdir(neat_dir)):
                 print(
                     f'Successfully downloaded all images in {(time.time() - initial) / 60:.2f} minutes')
-                with open(neat_dir + '/tomoe.html', 'x') as f:
+                with open(neat_dir + '/tomoe.html', 'x', encoding="utf-8") as f:
                     f.write('<html><center><body>')
-                    f.write(f'<h1>{title}</h1>')
+                    f.write(f"<h1>{parser['details']['id']}</h1>")
    
                     for i in img:
                         ## get after last slash in img, example /1.jpg
@@ -65,7 +71,7 @@ async def get_nh(id: int = choose().nhentai):
                     f.write('</body></center></html>')
                     f.close()
 
-                    print(f'Static gallery saved to {neat_dir}/tomoe.html')
+                    
                     print(f'Directory: {os.path.abspath(neat_dir)}')
 
         
